# 123-Fusion
Converts 123D design CAD files into Fusion 360 CAD files

[![licence](https://img.shields.io/github/license/mashape/apistatus.svg)](https://github.com/bennymeg/AcademicEmailVerifier/blob/master/LICENSE)
[![](https://img.shields.io/pypi/v/:packageName.svg)](https://pypi.org/pypi/fusion123/)

<!-- ___
🚧**NOTE:** this repository is still a work in progress, it has not been deployed to PyPi yet. In order to use it, please execute the converter script directly.
```
python converter.py [path/to/*.123dx]
```

* _if no file path is provided, the script will use the current script directory_
___ -->

## Getting Started

These instructions will get you a copy of the project up and running on your local machine for development and testing purposes. See deployment for notes on how to deploy the project on a live system.

### Prerequisites

You will need to install python 3 in order to use this software

### Installing

```
pip install fusion123
```
NOTE: the PyPi module name is _different_ then the repository name

### Running

```
python fusion123 [path/to/*.123dx]
```

### Coding style tests

Please use PyLint (Default linter on VS Code) to lint your code before submitting a PR.

## Contributing

Please read [CONTRIBUTING.md](https://github.com/bennymeg/123-Fusion/CONTRIBUTING.md) for details on our code of conduct, and the process for submitting pull requests to us.

## Versioning

We use [SemVer](http://semver.org/) for versioning. For the versions available, see the [tags on this repository](https://github.com/bennymeg/123-Fusion/tags). 

## Authors

**Benny Megidish**

_See also the list of [contributors](https://github.com/bennymeg/123-Fusion/contributors) who participated in this project._

## License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE) file for details
